@@ -1,3 +1,6 @@
+import xml.etree.ElementTree as et
+
+
 ###########################################################################
 #
 # this module meant to provide intuitive functions to work with xml files
@@ -58,6 +61,7 @@ def nodes_to_dict(nodes, att_key):
 def get_all_direct_child_nodes(node):
     return list(node)
 
+
 # will return the text (inner html) of a given node
 def get_text_from_node(node):
     text = node.text
@@ -88,7 +92,6 @@ def get_node_att(node, att_name):
 
 # will return an xml file
 def read_xml_file(xml_path):
-    import xml.etree.ElementTree as et
     return et.parse(xml_path)
 
 
@@ -102,14 +105,13 @@ def save_xml_file(xml_file, xml_path, add_utf_8_encoding=False):
 
 # will create an xml file
 def create_xml_file(root_node_tag, output_file):
-    import xml.etree.ElementTree as et
     xml = et.Element(root_node_tag)
     tree = et.ElementTree(xml)
     save_xml_file(tree, output_file)
     return tree
 
 
-def add_node(doc, node_tag, att_dict={}, node_text=None, parent_node=None):
+def add_new_node(doc, node_tag, att_dict={}, node_text=None, parent_node=None):
     """
     Will add a node to a certain (relative) location
 
@@ -120,25 +122,62 @@ def add_node(doc, node_tag, att_dict={}, node_text=None, parent_node=None):
     """
     if parent_node is None:
         parent_node = doc.getroot()
-    import xml.etree.ElementTree as et
     node = et.SubElement(parent_node, node_tag, att_dict)
     if node_text is not None:
         set_node_text(node, node_text)
     return node
 
 
+# will add an existing node to a parent node
+def add_node(parent_node, child_node):
+    direct_children = get_all_direct_child_nodes(parent_node)
+    location = 0
+    if direct_children:
+        location = len(direct_children)
+    parent_node.insert(location, child_node)
+
+
+# will add a bunch of already existing nodes to a parent node
+def add_nodes(parent_node, child_nodes):
+    for child_node in child_nodes:
+        add_node(parent_node, child_node)
+
+
 # will add attribute to a given node
 def set_node_atts(node, atts_dict):
     for key, val in atts_dict.items():
         node.set(key, val)
 
 
+# will merge xml1 with xml2 and return a new xml comprising both of them.
+# NOTICE: this function will compare the direct root child nodes and merge/append them.
+def merge_xml1_with_xml2(xml1, xml2):
+    xml2_root = get_root_node(xml2)
+    xml2_direct_children = get_all_direct_child_nodes(xml2_root)
+    for xml1_child in get_all_direct_child_nodes(get_root_node(xml1)):
+        parent_node = None
+        for xml2_child in xml2_direct_children:
+            # if the direct child already exists, add the appended tag content to the existing one
+            if xml1_child.tag == xml2_child.tag:
+                parent_node = xml2_child
+                break
+
+        if parent_node:
+            xml1_direct_children = get_all_direct_child_nodes(xml1_child)
+            add_nodes(parent_node, xml1_direct_children)
+
+        else:
+            add_node(xml2_root, xml1_child)
+
+    return xml2
+
+
 # Will turn a simple dictionary to an xml file, by hierarchical order
 def simple_dict_to_xml(xml_dict, root_name, output_path):
     # will unpack the parent recursively
     def recursive_unpack_parent(parent_dict, parent=None):
         for key, val in parent_dict.items():
-            parent = add_node(xml, key, parent_node=parent)
+            parent = add_new_node(xml, key, parent_node=parent)
             if type(val) is dict:
                 recursive_unpack_parent(val, parent)
 
@@ -160,4 +199,3 @@ def _get_nodes(node, node_tag, node_att_name=None, node_att_val=None):
         else:
             selector = node_tag + "/[@" + node_att_name + "]"
     return node.findall(selector)
-
